.. _technical_configuration:

Technical configuration
-----------------------

.. tabularcolumns:: |p{3cm}|p{6cm}|p{1.5cm}|p{1.8cm}|p{2cm}|
.. list-table::
    :header-rows: 1

    * - Property
      - Description
      - I18n
      - Required
      - Unique

    * - Statuses
      - draft, published
      - no
      - yes
      - no

    * - Page type
      - Menu page, inner page, api page, api&menu page
      - no
      - yes
      - no

    * - Date of creation
      - The date of page creation
      - no
      - yes
      - no

    * - Date of modification
      - The date of page last modification
      - no
      - yes
      - no
